@@ -329,7 +329,7 @@ extract.GDINA <- function(object,what,SE.type = 2,...){
                 item.names = object$options$item.names,
                 itemprob.history = object$diagnos$itemprob.matrix,
                 Kj = {rowSums(extract(object,"Q"))},
-                latent.var = object$options$latent.var,
+                no.bugs = object$options$no.bugs,
                 LC.labels = object$technicals$LC.labels,
                 LCprob.parm = object$LC.prob,
                 LCpf.parm = {
